unit PayCashTypes;

//  PayCash
// (C) 2000 PayCash   www.paycash.ru

interface

uses windows;

const
  MaxContractCurrencyOptionsCount = 16 ;

type
//  

//  

  TConfirmAction = (caAccept, caReject, caAbort);
//  TConfirmAction        = DWord;

//  
  TNanoTime             = int64;  // 
  TCypher               = DWord;  //    -
  TPreciseSum           = int64;  //   
  TBankId               = DWord;  //   
  TAccountID            = int64;  //    
  TCurrencyCode         = DWord;  //    PayCash
  TProcResult           = Word;   // 
  TSignatureStatus      = DWord;  //  
  TContractTermsFormat  = DWord;  //   
  
// 
  TIncomingPaymentID    = packed array [0..4] of DWord;
  TShortDescription     = packed array [0..47] of char;
  TStringsArray         = array [0..0] of PChar;

// 
  PStringsArray         = ^TStringsArray;

// 

//  (    )
  TCurrencyAndSum = packed record
    Currency: TCurrencyCode;
    Sum: TPreciseSum;
    end;

//     PayCash (   
//     ).
  TBankAndAccountID = packed record
    BankID              : TBankID;
    AccountID           : TAccountID;
    end;

//   
  TParamsRecord = record
    ParamCount          : DWord;
    ParamNames          : PStringsArray;
    ParamValues         : PStringsArray;
    end;

//  
  TReplyResource = packed record
    ResourceCachePeriod : DWord;  //   
    ResourceFlags       : DWord;  //  
    ResourceType        : DWord;  //   ( . rt* )
    ResourceSize        : DWord;  //  
    ResourceBody        : PChar;  // 
    end;

//  " " 
  TContractData = packed record
    PayeeRegDataSize    : DWord;
    PayeeRegData        : pointer;
    ShortDescription    : TShortDescription;
    PaymentDelay        : DWord;
    ContractDateTime    : TNanoTime;
    ProcessingOptions   : DWord;
    CurrencyOptionsCount: DWord;
    CurrencyOptions     : packed array [0..MaxContractCurrencyOptionsCount - 1]
      of TCurrencyAndSum;
    MoneyDestination    : TBankAndAccountID;
    ContractTermsFormat : TContractTermsFormat;
    ContractTermsDataSize: DWord;
    ContractTermsData   : pointer;
    ContractSigner      : TCypher;
    end;

//         
  TIncomingPaymentInfo = packed record
    PayeeRegDataSize    : DWord;
    PayeeRegData        : pointer;
    IncomingPaymentID   : TIncomingPaymentID;
    MoneyDestination    : TBankAndAccountID;
    PaymentCurrency     : TCurrencyCode;
    PaymentSum          : TPreciseSum;
    ContractSigner      : TCypher;
    SignatureStatus     : TSignatureStatus;
    PaymentDelay        : DWord;
    ContractDateTime    : TNanoTime;
    end;

//        .
  TPaymentAuthorizationInfo = packed record
    ErrorCode           : TProcResult;
    PayeeRegDataSize    : DWord;
    PayeeRegData        : pointer;
    IncomingPaymentID   : TIncomingPaymentID;
    AuthorizationTime   : TNanoTime;
    Recovery            : Boolean;
    MoneyDestination    : TBankAndAccountID;
    AccountCurrency     : TCurrencyCode;
    CreditSum           : TPreciseSum;
    PaymentCurrency     : TCurrencyCode;
    PaymentSum          : TPreciseSum;
    ContractSigner      : TCypher;
    ContractSignatureStatus: TSignatureStatus;
    PaymentDelay        : DWord;
    ContractTime        : TNanoTime;
    end;

//  
  TShopProc_GetMoneyRequest = procedure (
          ErrorCode     : TProcResult;
          Cypher        : TCypher;
    const ContractModifier: TParamsRecord;
          PayerAddress  : PChar;
    out   RequestMode     : word;
    out   ContractData    : TContractData;
    out   ReplyResource   : TReplyResource); stdcall;

  TShopProc_GetIncomingPaymentApproval = procedure (
          ErrorCode     : TProcResult;
    const PaymentInfo   : TIncomingPaymentInfo;
    var   ShortDescription: TShortDescription; // in/out
    out   ConfirmAction   : TConfirmAction;
    out   BankConnection  : DWord;
    out   ReplyResource   : TReplyResource); stdcall;

  TShopProc_PaymentAuthorizationResult = procedure(
    const PaymentAuthorizationInfo: TPaymentAuthorizationInfo;
    out   ReplyResource   : TReplyResource); stdcall;

//       

  TShopProcsTable = packed record
    GetMoneyRequest: TShopProc_GetMoneyRequest;
    GetIncomingPaymentApproval: TShopProc_GetIncomingPaymentApproval;
    PaymentAuthorizationResult: TShopProc_PaymentAuthorizationResult;
    end;

const

// ************************************************************************ //
//                                                          //
// ************************************************************************ //

// Request mode
  rmRequest         = 1; //    
  rmAlreadyPaid     = 2; //   
  rmDoesNotQualify  = 3; // ""  
  rmShopError       = 4; //   

//     
  pmDefault         = MaxDWord; //     .
  pmOnLine          = $10;      //  On-line.
  pmEMail           = $20;      // E-mail
  pmOnLine_HTTPOnly = $40;      //  On-line,   HTTP.

// ProcessingOptions
  proAcceptPaymentWithoutConfirmation = 1;

//  
  ssNoSignature     = 1; //  .
  ssUnknown         = 2; //  .
  ssError           = 3; //     .
  ssInvalid         = 4; //  .
  ssUnknownPeriod   = 5; //    .
  ssOutOfPeriod     = 6; //   ,    
                         //    .
  ssValid           = 7; //  

//  
(*
  caAccept          = 1; // 
  caReject          = 2; // 
  caAbort           = 3; // 
*)

//  
  rtNoResource	  = 1; //  .   
    // "" ,   ,
    //     WWW- .
  rtHTML	  = 2; //  HTML-.
  rtHTTP	  = 3; //    HTTP-.    
    // WWW-    ,   
    //      HTTP-.
  rtURL	          = 4; // URL  : WWW-
    //         URL.
  rtRetrieveURL	  = 5; // URL,  -    
    //  (  ).

//    
  ResourceFlag_UseCompression = $0001;

// ContractTermsFormat
  ctf_Win1251 = 1;

// ************************************************************************ //
//                                                                //
// ************************************************************************ //

// GetMoneyRequest
  SUCCESS = 1;
  //     GetMoneyRequest.
  pmipIncorrectRequestData = 1001;
  //       - (!).
  pmipUnknownResourceType = 1002;
  //    (  ResourceType  TReplyResource
  //  ,  -).
  pmipIncorrectRequestMode = 1005;
  //   RequestMode (   
  //  RequestMode).
  mrUnknownContractType = 5;
  //    (!).
  mrInvalidContractDateTime = 6;
  //      ( ContractDateTime
  //  TContractData)    -.
  mrContractHasAlreadyExpired = 7;
  //   .   -  
  //   ( ContractDateTime)      ( PaymentDelay).
  mrNoPaymentSum = 8;
  //      .
  mrNonPositivePaymentSum = 9;
  //     .
  mrUnknownMoneyDestinationType = 10;
  //     (!).
  mrAccountNotFound = 11;
  //     -     
  // (,         ).
  mrAccountReadError = 12;
  //      .
  mrNoActualBankKeys = 13;
  //         
  // (  ,      ,    ).
  //     ,    .
  mrAccountClosed = 14;
  //     ,      
  // (     ).
  mrIncorrectPaymentOption = 15;
  //     (       
  // ).
  mrUnknownContractFormat = 16;
  //      (!).
  mrTooLengthyContract = 17;
  //    .     
  //     200  (200 * 1024 ).
  mrInadmissibleCharacterInContractBody = 18;
  //     .
  mrInadmissibleCharacterInContractDescription = 19;
  //       ( ShortDescription
  //  TContractData).
  mrPseudonymNotIndicated = 20;
  //    ,     .
  mrPseudonymNotFound = 21;
  //         -.
  mrPseudonymReadError = 22;
  //     .
  mrEncryptionKeyOutOfValidityTimePeriod = 23;
  //           
  // .
  mrSignatureKeyOutOfValidityTimePeriod = 24;
  //           
  // .
  mrContractSigningError = 25;
  //     .
  mrMessageDispatchError = 26;
  //      " "  (
  //   ) .
  mrIncorrectContractFormat = 27;
  //    (!).
  mrTechError = 100;
  //    -

// GetIncomingPaymentApproval
  UnknownAcceptParameters = 50;
  //   "" .    
  //     -  .

//PaymentAuthorizationResult
  peeSUCCESS = 1;
  peeIncorrectMessageFormat = 2;
  //   () 
  peeUnknownSessionKeyType = 3;
  //     
  peePayerDataIsTooSmall = 4;
  //       (  )
  peeSumIsNotPositive = 5;
  //   
  peeNoInterbankingAgreement = 6;
  //      
  peePayeeBankKeysAreNotActual = 7;
  //  ,   ,       
  peeTargetAccountNotFound = 8;
  //    
  peeTargetAccountReadError = 9;
  //    
  peeCurrencyParamReadError = 10;
  //      
  peeCurrencyIsNotOperational = 11;
  //     
  peeConversionParamReadError =12;
  //     
  peeCurrencyConversionDisabled = 13;
  //        
  peePaymentSumTooSmallForComm = 14;
  //        
  peePayerBankKeyNotActual = 15;
  //  ,    
  peeIncorrectPayerData = 16;
  //    
  peeUnknownPayerKey = 17;
  //     
  peeUnknownVASignaturePubKey = 18;
  //       
  peeUnknownPayOrderType = 19;
  //    
  peeUnknownExpositionSignature = 20;
  //   ExpositionSignature
  peeIncorrectPayerDataLength = 21;
  //        
  peeInadmissiblePaymentCurrency = 22;
  //   
  peeVirtualAccountReadError = 23;
  //       
  peeVAKeyAbsent = 24;
  //        
  peeNoVAExposition = 25;
  //        
  peeVAExpositionIsEmpty = 26;
  //        
  peePayerDataConflictWithPayeeData = 27;
  //         
  peeNoKeyForVACurrency = 28;
  //      
  peeNoMoneyToOpenVAccount = 29;
  //       
  peeInvalidPayerSignature = 30;
  //   
  peePaymentIsTooOld = 31;
  //  
  peeOldReceiptsConfirmationAbsent = 32;
  //     
  peePaymentCancelled = 33;
  //   
  peeRepeatDoesNotCoincideWithOriginal = 34;
  //       
  peePaymentRejectedByBank = 35;
  //      
  peeTargetAccountIsLocked = 36;
  //   
  peeTargetAccountIncomingsAreDisabled = 37;
  //     
  peeTargetAccountIsClosed = 38;
  //   
  peeAccountCurrencyLocked = 39;
  //      (  )
  peeNotEnoughMoneyForPaymentInVA = 40;
  //        
  peeArchiveOrderCreationError = 41;
  //        
  peeArchiveOrderModificationError = 42;
  //        
  peeVAModifyingError = 43;
  //     
  peeNonPositiveOrderID = 44;
  //  ()   
  peeMoneyHasExpired = 45;
  //     
  peePaymentsViaPayeeOnly = 46;
  //         
  peeAccountTimeParamError = 47;
  //     
  peeTechnicalError = 48;
  //    

implementation

end.
